@@ -757,7 +757,6 @@ def modifyFilesNewGraph(version,group,name,type_graph,project_name):
 
     graph_version = version
     group_graph = group
-    name_graph = name
     try:
         with open('springlabs_django.json') as file:
             data = json.load(file)
@@ -767,12 +766,15 @@ def modifyFilesNewGraph(version,group,name,type_graph,project_name):
     else:
         versions_detail = data['versions_detail']
         old_graphs = []
-        names_no_valid = []
+        old_graphs_version = []
+        index_version_modify = 0
         # Recorremos todas las versiones
-        for versions in versions_detail:
+        for index, versions in enumerate(versions_detail):
             # Si la versión del ciclo es en donde vamos a insertar el graph
             if versions['version'] == graph_version:
                 groups_detail = versions["groups_detail"]
+                index_version_modify = index
+                old_graphs_version = list(versions['graph_list'])
                 # Recorremos todos los grupos de esa versión
                 for group_detail in groups_detail:
                     # Si el grupo del ciclo es en donde vamos a insertar el graph
@@ -819,6 +821,16 @@ def modifyFilesNewGraph(version,group,name,type_graph,project_name):
     find_import_schema = "from .types import"
     find_import_api = f"from .{group}.schema import"
     find_query_api = f"class Query("
+    # Arma FIND de class Query api.py
+    for index, old_graph in enumerate(old_graphs_version):
+        old_graph_name = old_graph
+        if index == 0:
+            find_query_api = find_query_api+f"{old_graph_name}"
+        else:
+            find_query_api = find_query_api+f", {old_graph_name}"
+    base_new_query_api = str(find_query_api)
+    find_query_api = find_query_api + ", graphene.ObjectType):"
+    # Arma find de import schema.py e import api.py 
     for index, old_graph in enumerate(old_graphs):
         if old_graph != "ExampleDjango":
             old_graph_name = old_graph.capitalize()
@@ -828,13 +840,10 @@ def modifyFilesNewGraph(version,group,name,type_graph,project_name):
             
             find_import_schema = find_import_schema+f" {old_graph_name}Type"
             find_import_api = find_import_api+f" {old_graph_name}Queries"
-            find_query_api = find_query_api+f"{old_graph_name}Queries"
         else:
             find_import_schema = find_import_schema+f", {old_graph_name}Type"
             find_import_api = find_import_api+f", {old_graph_name}Queries"
-            find_query_api = find_query_api+f", {old_graph_name}Queries"
-    base_new_query_api = str(find_query_api)
-    find_query_api = find_query_api + ", graphene.ObjectType):"
+    
     # Elimina ExampleDjango de archivo schema.py y types.py
     if delete_example==True:
         # Elimina ExampleDjango de archivo schema.py
@@ -875,17 +884,36 @@ def modifyFilesNewGraph(version,group,name,type_graph,project_name):
         
         new_import_schema = f"from .types import {name.capitalize()}Type"
         new_import_api = f"from .{group}.schema import {name.capitalize()}Queries"
-        new_query_api = f"class Query({name.capitalize()}Queries"
+        new_query_api = "class Query("
+
+        counter = 0
+        index_replace_example = 0
+        for index, old_graph in enumerate(old_graphs_version):
+            if old_graph != "ExampleDjangoQueries":
+                if index == 0:
+                    new_query_api = new_query_api+f"{old_graph}"
+                else:
+                    new_query_api = new_query_api+f", {old_graph}"
+            elif old_graph == "ExampleDjangoQueries" and counter != 0:
+                if index == 0:
+                    new_query_api = new_query_api+f"{old_graph}"
+                else:
+                    new_query_api = new_query_api+f", {old_graph}"
+            else:
+                if index == 0:
+                    new_query_api = new_query_api+f"{name.capitalize()}Queries"
+                else:
+                    new_query_api = new_query_api+f", {name.capitalize()}Queries"
+                index_replace_example = index
+                counter = counter+1
         for index, old_graph in enumerate(old_graphs):
             if old_graph != "ExampleDjango":
                 if index == 0:
                     new_import_schema = new_import_schema+f" {old_graph.capitalize()}Type"
                     new_import_api = new_import_api+f" {old_graph.capitalize()}Queries"
-                    new_query_api = new_query_api+f" {old_graph.capitalize()}Queries"
                 else:
                     new_import_schema = new_import_schema+f", {old_graph}Type"
                     new_import_api = new_import_api+f", {old_graph.capitalize()}Queries"
-                    new_query_api = new_query_api+f", {old_graph.capitalize()}Queries"
         index_graph_example_django = False
         try:
             with open('springlabs_django.json') as file:
@@ -894,16 +922,13 @@ def modifyFilesNewGraph(version,group,name,type_graph,project_name):
             message = "Ocurrio un error interno al actualizar archivo springlabs_django.json"
             errors.append([message, True])
         else:
-            objGraph = {
-                "graph_name": name,
-                "graph_type": type_graph
-            }
             versions_detail = data['versions_detail']
             # Recorremos todas las versiones
             for index_versions, versions in enumerate(versions_detail):
                 # Si la versión del ciclo es en donde vamos a insertar el graph
                 if versions['version'] == version:
                     groups_detail = versions["groups_detail"]
+                    
                     # Recorremos todos los grupos de esa versión
                     for index_groups, group_detail in enumerate(groups_detail):
                         # Si el grupo del ciclo es en donde vamos a insertar el graph
@@ -919,7 +944,8 @@ def modifyFilesNewGraph(version,group,name,type_graph,project_name):
                 index_version = index_graph_example_django[0]
                 index_groups = index_graph_example_django[1]
                 index_graph = index_graph_example_django[2]
-                data['versions_detail'][index_versions]['groups_detail'][index_groups]['graph'].pop(index_graph)
+                data['versions_detail'][index_version]['graph_list'][index_replace_example] = f"{name.capitalize()}Queries"
+                data['versions_detail'][index_version]['groups_detail'][index_groups]['graph'].pop(index_graph)
             try:
                 with open("springlabs_django.json", "w") as file:
                     file.write(json.dumps(data))
@@ -930,6 +956,23 @@ def modifyFilesNewGraph(version,group,name,type_graph,project_name):
         new_import_schema = find_import_schema + f", {name.capitalize()}Type"
         new_import_api = find_import_api + f", {name.capitalize()}Queries"
         new_query_api = base_new_query_api + f", {name.capitalize()}Queries"
+        # Modifica graph_list
+        try:
+            with open('springlabs_django.json') as file:
+                data = json.load(file)
+        except:
+            message = "Ocurrio un error interno al actualizar archivo springlabs_django.json"
+            errors.append([message, True])
+        else:
+            data['versions_detail'][index_version_modify]['graph_list'].append(f"{name.capitalize()}Queries")
+            try:
+                with open("springlabs_django.json", "w") as file:
+                    file.write(json.dumps(data))
+            except:
+                message = "Ocurrio un error interno al actualizar archivo springlabs_django.json"
+                errors.append([message, True])
+        
+        
     new_query_api = new_query_api + ", graphene.ObjectType):"
     # Escribe nuevo graph en archivo schema.py
     path = f"graphql_api/v{version}/{group}/schema.py"
@@ -1013,7 +1056,21 @@ def modifyFilesNewGroup(version, group,project_name):
     if result == False:
         errors.append([message, True])
 
+    
     find="# Our custom libraries (Managed by SPRINGLABS_DJANGO)"
+    content=f"from .{group} import views as {group}_views"
+    message, result = appendContent(path=privatepath,
+        content=content,
+        find=find)
+    if result == False:
+        errors.append([message, True])
+
+    message, result = appendContent(path=publicpath,
+        content=content,
+        find=find)
+    if result == False:
+        errors.append([message, True])
+
     content=f"from .{group}.schema import ExampleDjangoQueries"
     path=f"graphql_api/v{version}/api.py"
     message, result = appendContent(path=path,
@@ -1022,6 +1079,36 @@ def modifyFilesNewGroup(version, group,project_name):
     if result == False:
         errors.append([message, True])
 
+    try:
+        with open('springlabs_django.json') as file:
+            data = json.load(file)
+    except:
+        message = "Ocurrió un problema interno al leer archivo (springlabs_django.json)"
+        return message, False
+
+    versions_detail=data["versions_detail"]
+    version_data=None
+    for obj in versions_detail:
+        if obj["version"]==version:
+            if "graph_list" in obj:
+                version_data=obj["graph_list"]
+            else:
+                version_data=[]
+
+    if version_data!=None:
+        content="class Query("
+        for obj in version_data:
+            content=content+obj+", "
+        find=content+"graphene.ObjectType):"
+        content=content+"ExampleDjangoQueries, graphene.ObjectType):"
+        message, result=findNReplace(path, content, find)
+        if result == False:
+            errors.append([message, True])
+
+    else:
+        message = "Ocurrió un problema interno, al leer archivo (springlabs_django.json)"
+        return message, False
+
     for error in errors:
         if error[1] == True:
             return error[0], False
@@ -1034,6 +1121,7 @@ def createDirectoriesNewGroup(version, group, project_name):
     os.chdir(f"api/v{version}")
     os.mkdir(group)
 
+
     base_serializers_py = "/core/new_version/api/baseSerializers.py"
     base_views_py = "/core/new_version/api/baseViews.py"
     
@@ -1090,4 +1178,5 @@ def createDirectoriesNewGroup(version, group, project_name):
     for error in errors:
         if error[1] == True:
             return error[0], False
+
     return "OK", True
\ No newline at end of file
