@@ -65,6 +65,7 @@ def createVersion(version, project_name, old_versions):
         objVersionDetail = {
             "version": version,
             "groups": ["users"],
+            "graph_list":["ExampleDjangoQueries"],
             "groups_detail": [
                 {
                     "group": "users",
@@ -304,8 +305,12 @@ def createGroup(version, group, project_name):
         for obj in data["versions_detail"]:
             if obj["version"]==version:
                 obj["groups"].append(group)
-                obj["groups_detail"]=[]
+                if not "groups_detail" in obj:
+                    obj["groups_detail"]=[]
                 obj["groups_detail"].append(objGroupDetail)
+                if not "graph_list" in obj:
+                    obj["graph_list"]=[]
+                obj["graph_list"].append("ExampleDjangoQueries")
         try:
             with open("springlabs_django.json", "w") as file:
                 file.write(json.dumps(data))
@@ -314,11 +319,9 @@ def createGroup(version, group, project_name):
             errors.append([message, True])
     for error in errors:
         if error[1] == True:
-            print("errros$$$$$$$$$$")
             message, result = reverseChanges(project_name=project_name)
             os.chdir("..")
             os.remove(project_name + ".zip")
             os.chdir(project_name)
             return error[0], False
-    print("creado utls")
     return "OK", True
